/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.worksinglewage.dao;

import com.jeeplus.common.persistence.CrudDao;
import com.jeeplus.common.persistence.annotation.MyBatisDao;
import com.jeeplus.modules.worksinglewage.entity.WorkSingleWageRecord;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 通知通告记录DAO接口
 * @author jeeplus
 * @version 2014-05-16
 */
@MyBatisDao
public interface WorkSingleWageRecordDao extends CrudDao<WorkSingleWageRecord> {

	/**
	 * 插入通知记录
	 * @param workSingleWageRecordList
	 * @return
	 */
	public int insertAll(List<WorkSingleWageRecord> workSingleWageRecordList);
	/**
	 * 插入通知记录
	 * @param workSingleWageRecordOfficeList
	 * @return
	 */
	public int insertOfficeAll(List<WorkSingleWageRecord> workSingleWageRecordOfficeList);

	/**
	 * 根据通知ID删除通知记录
	 * @param workSingleWageRecord 通知ID
	 * @return
	 */
	public int deleteByworkSingleWageId(WorkSingleWageRecord workSingleWageRecord);

	public List<WorkSingleWageRecord> findUsers(WorkSingleWageRecord workSingleWageRecord);
	public List<WorkSingleWageRecord> findOffices(WorkSingleWageRecord WworkSingleWageRecord);
	public int findUserCount(@Param("id") String id, @Param("userId") String userId, @Param("branchOffice") String branchOffice);
	public int findOfficeCount(@Param("id") String id, @Param("officeId") String officeId, @Param("branchOffice") String branchOffice);
	public void deleteByWageId(@Param("wageId") String wageId);

}

   


